@@ -153,7 +153,14 @@ class PostgresEventLogStorage(SqlEventLogStorage, ConfigurableClass):
                 (res[0] + "_" + str(res[1]),),
             )
 
-        if event.is_dagster_event and event.dagster_event.asset_key:
+        if (
+            event.is_dagster_event
+            and event.dagster_event.is_step_materialization
+            and event.dagster_event.asset_key
+        ):
+            # Currently, only materializations are stored in the asset catalog.
+            # We will store observations after adding a column migration to
+            # store latest asset observation timestamp in the asset key table.
             self.store_asset(event)
 
     def store_asset(self, event):
